VERONICA -- Rollouts

# Rollout Pipeline

New Rollout
Chain ID *
Ceiling USD *
On Exceed
Created By
State

ID | State | Chain ID | Ceiling USD | Created At | Created By | Actions
--- | --- | --- | --- | --- | --- | ---
Loading...

Select a rollout to view details.
Detail
ID
Chain ID
Ceiling USD
On Exceed
Created By
Created At
Simulation Result
State History

- No transitions yet.

Confirm Action

Actor (your name)
Enter API Key

Provide your X-Veronica-Key to access rollouts.

API Key